/*
 * gpio_test.c
 *
 *  Test app for the IBM PowerPC 405 GPIO Driver.  For use on the DHT-Walnut 
 *  for the Green Media LED.
 *
 *  Greg Jurman mahi@imahi.net or megamahi@gmail.com
 *  March, 2006
 *
 * Copyright 2006 iMahi.net.
 *
 *  This program is free software; you can redistribute  it and/or modify it
 *  under  the terms of  the GNU General  Public License as published by the
 *  Free Software Foundation;  either version 2 of the  License, or (at your
 *  option) any later version.
 *
 *  THIS  SOFTWARE  IS PROVIDED   ``AS  IS'' AND   ANY  EXPRESS OR IMPLIED
 *  WARRANTIES,   INCLUDING, BUT NOT  LIMITED  TO, THE IMPLIED WARRANTIES OF
 *  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
 *  NO  EVENT  SHALL   THE AUTHOR  BE	LIABLE FOR ANY   DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED   TO, PROCUREMENT OF  SUBSTITUTE GOODS  OR SERVICES; LOSS OF
 *  USE, DATA,  OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 *  ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  You should have received a copy of the  GNU General Public License along
 *  with this program; if not, write  to the Free Software Foundation, Inc.,
 *  675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <fcntl.h>
#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <linux/types.h>
#include <linux/ioctl.h>
#include "ppc405_gpio.h"

int main (int argc, char *argv[]) {	
	
	//Device has a Major 10, Minor 185 just 'mknod /dev/ppc405_gpio c 10 185' 
	//if it doesn't exist.
	int fd = open("/dev/ppc405_gpio", O_RDWR);
	
	struct ppc405gpio_ioctl_data gpio_ioctl;
	int data;

	if(fd < 0) {
		fprintf(stderr, "Unable to open /dev/ppc405_gpio!\n");
	}
	
	gpio_ioctl.device=0; //Device is always 0
	gpio_ioctl.mask=0x20000000; //Change just the bit we need to change
	
	char state;

	if(argc < 2) {
		fprintf(stderr, "Usage gpio_test 0|1\n");
		exit(1);
	} else {
		sscanf(argv[1], "%c", &state);
		switch(state) {
			case '1':
				gpio_ioctl.data=0x20000000;
				break;
			case '0':
				gpio_ioctl.data=0x00000000;
				break;
			default:
				fprintf(stderr, "Usage: ./gpio_test 0|1\n");
				break;
		}

		ioctl(fd, PPC405GPIO_TRISTATE, (void *)&gpio_ioctl); //Do the call
	}

	close(fd);
	return 0;
}
